==> liblxqt_0.14.1.1+rb2.orig.tar.xz: liblxqt-0.14.1.1+rb2/translations/liblxqt_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Дијалог</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation type="unfinished">Грешка Рејзоровог менаџера напајања</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation type="unfinished">Хибернација није успела.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Хибернирај</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Суспендуј</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Угаси</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Суспендовање Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Желите ли заиста да суспендујете ваш рачунар?&lt;p&gt;Ово поставља ваш рачунар у стање смањене потрошње енергије. Стање система није очувано ако дође до нестанка струје.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Хибернација Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Желите ли заиста да хибернирате ваш рачунар?&lt;p&gt;Ово поставља ваш рачунар у стање смањене потрошње енергије. Стање система је очувано ако дође до нестанка струје.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Поновно покретање Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Желите ли заиста да поново покренете ваш рачунар? Несачуван рад ће бити изгубљен...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Гашење Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Желите ли заиста да угасите ваш рачунар? Несачуван рад ће бити изгубљен...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Одјава Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Желите ли заиста да се одјавите? Несачуван рад ће бити изгубљен...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Грешка Рејзоровог менаџера напајања</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Хибернација није успела.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Суспендовање није успело.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Закључај екран</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="162"/>
        <location filename="../lxqtscreensaver.cpp" line="168"/>
        <location filename="../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Грешка при активацији чувара екрана</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Грешка при покретању чувара екрана. Грешка у синтакси аргумената xdg-screensaver-а.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Грешка при покретању чувара екрана. Уверите се да имате xdg-screensaver инсталиран и покренут.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Грешка при покретању чувара екрана. Радња „активирај“ није успела. Уверите се да имате xdg-screensaver инсталиран и покренут.</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> liblxqt_0.15.0.orig.tar.xz: liblxqt-0.15.0/translations/liblxqt_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Дијалог</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>LXQt Power Manager Error</source>
        <translation type="unfinished">Грешка Рејзоровог менаџера напајања</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>Hibernate failed.</source>
        <translation type="unfinished">Хибернација није успела.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="118"/>
        <source>Hibernate</source>
        <translation>Хибернирај</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="125"/>
        <source>Suspend</source>
        <translation>Суспендуј</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="132"/>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="139"/>
        <source>Shutdown</source>
        <translation>Угаси</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="146"/>
        <source>Logout</source>
        <translation>Одјави се</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Suspend</source>
        <translation>Суспендовање Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Желите ли заиста да суспендујете ваш рачунар?&lt;p&gt;Ово поставља ваш рачунар у стање смањене потрошње енергије. Стање система није очувано ако дође до нестанка струје.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Hibernate</source>
        <translation>Хибернација Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Желите ли заиста да хибернирате ваш рачунар?&lt;p&gt;Ово поставља ваш рачунар у стање смањене потрошње енергије. Стање система је очувано ако дође до нестанка струје.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Reboot</source>
        <translation>Поновно покретање Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Желите ли заиста да поново покренете ваш рачунар? Несачуван рад ће бити изгубљен...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Shutdown</source>
        <translation>Гашење Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Желите ли заиста да угасите ваш рачунар? Несачуван рад ће бити изгубљен...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>LXQt Session Logout</source>
        <translation>Одјава Рејзорове сесије</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="199"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Желите ли заиста да се одјавите? Несачуван рад ће бити изгубљен...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>LXQt Power Manager Error</source>
        <translation>Грешка Рејзоровог менаџера напајања</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <source>Hibernate failed.</source>
        <translation>Хибернација није успела.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>Suspend failed.</source>
        <translation>Суспендовање није успело.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="161"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="165"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="243"/>
        <source>Lock Screen</source>
        <translation>Закључај екран</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
